@@ -1,7 +1,11 @@
 import arrow
 from datetime import timedelta
 import os
+
+from gitmodel import exceptions
+
 from pyramid import testing
+from pyramid_beaker import set_cache_regions_from_settings
 
 from cms.views import CmsViews
 from cms.tests.utils import BaseTestCase, RepoHelper
@@ -13,12 +17,17 @@ class TestViews(BaseTestCase):
         super(TestViews, self).setUp()
         self.repo = RepoHelper.create(os.path.join(os.getcwd(), '.test_repo'))
         languages = "[('eng_UK', 'English'), ('swh_KE', 'Swahili (Kenya)')]"
-        self.config = testing.setUp(settings={
+        settings = {
             'git.path': self.repo.path,
             'git.content_repo_url': '',
+            'cache.enabled': 'false',
+            'cache.regions': 'long_term',
+            'cache.long_term.expire': '1',
             'available_languages': languages,
-        })
-        self.views = CmsViews({}, testing.DummyRequest())
+        }
+        self.config = testing.setUp(settings=settings)
+        set_cache_regions_from_settings(settings)
+        self.views = CmsViews(testing.DummyRequest())
 
     def tearDown(self):
         self.repo.destroy()
@@ -71,3 +80,11 @@ class TestViews(BaseTestCase):
             set(['Test Page 8', 'Test Page 9']))
         self.assertEqual(
             [], self.views.get_featured_category_pages(category2.uuid))
+
+    def test_get_page_by_slug(self):
+        self.repo.create_pages(count=10)
+        p = self.views.get_page(None, 'test-page-1')
+        self.assertEqual(p['title'], 'Test Page 1')
+
+        with self.assertRaises(exceptions.DoesNotExist):
+            p = self.views.get_page(None, 'invalid-slug')
