@@ -4,11 +4,13 @@ from ast import literal_eval
 
 from beaker.cache import cache_region
 
+from gitmodel import exceptions
+
 from pyramid.view import view_config
 from pyramid.renderers import get_renderer
 from pyramid.decorator import reify
 from pyramid.response import Response
-from pyramid.httpexceptions import HTTPFound
+from pyramid.httpexceptions import HTTPFound, HTTPNotFound
 
 from unicore_gitmodels import models
 from cms import utils
@@ -18,8 +20,7 @@ CACHE_TIME = 'long_term'
 
 class CmsViews(object):
 
-    def __init__(self, context, request):
-        self.context = context
+    def __init__(self, request):
         self.request = request
         self.repo_path = self.request.registry.settings['git.path']
 
@@ -30,7 +31,8 @@ class CmsViews(object):
 
     @reify
     def get_available_languages(self):
-        langs = self.request.registry.settings.get('available_languages', '')
+        langs = self.request.registry.settings.get(
+            'available_languages', '[]')
         return literal_eval(langs)
 
     @reify
@@ -74,6 +76,7 @@ class CmsViews(object):
             for p in models.GitPageModel().filter(primary_category=category)
         ]
 
+    @cache_region(CACHE_TIME)
     def get_featured_category_pages(self, category_id):
         models = self.get_repo_models()
         category = models.GitCategoryModel().get(category_id)
@@ -85,9 +88,15 @@ class CmsViews(object):
         ]
 
     @cache_region(CACHE_TIME)
-    def get_page(self, uuid):
+    def get_page(self, uuid=None, slug=None):
         models = self.get_repo_models()
-        return models.GitPageModel().get(uuid).to_dict()
+        if uuid:
+            return models.GitPageModel().get(uuid).to_dict()
+        if slug:
+            pages = models.GitPageModel().filter(slug=slug)
+            if any(pages):
+                return pages[0].to_dict()
+        raise exceptions.DoesNotExist()
 
     @reify
     def get_top_nav(self):
@@ -109,6 +118,14 @@ class CmsViews(object):
     def content(self):
         return {'page': self.get_page(self.request.matchdict['uuid'])}
 
+    @view_config(route_name='flatpage', renderer='cms:templates/flatpage.pt')
+    def flatpage(self):
+        try:
+            page = self.get_page(None, self.request.matchdict['slug'])
+            return {'page': page}
+        except exceptions.DoesNotExist:
+            raise HTTPNotFound()
+
     @view_config(route_name='locale')
     def set_locale_cookie(self):
         if self.request.GET['language']:
